@@ -391,6 +391,14 @@ reading the calibration registers"
             return _BME280_PRESSURE_MAX_HPA
         return pressure
 
+    @property
+    def relative_humidity(self):
+        """
+        The relative humidity in RH %
+        returns None if humidity measurement is disabled
+        """
+        return self.humidity
+
     @property
     def humidity(self):
         """
